![Codecov branch](https://img.shields.io/codecov/c/github/firstof9/tplink-ess-lib/main?style=flat-square)
![GitHub commit activity (branch)](https://img.shields.io/github/commit-activity/m/firstof9/tplink-ess-lib?style=flat-square)
![GitHub last commit](https://img.shields.io/github/last-commit/firstof9/tplink-ess-lib?style=flat-square)
![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/firstof9/tplink-ess-lib?style=flat-square)
# tplink-ess-lib
Python Library for interfacing with TP-Link Easy Smart Switchs


TODO:
- [ ] Tests
- [ ] Clean up